@@ -3,6 +3,7 @@ from memtorch.map.Parameter import naive_map
 from .Linear import Linear
 from .Conv1d import Conv1d
 from .Conv2d import Conv2d
+from .Conv3d import Conv3d
 import torch
 import torch.functional as F
 import multiprocessing as mp
@@ -11,10 +12,11 @@ import itertools
 
 supported_module_parameters = {'<class \'torch.nn.modules.linear.Linear\'>': Linear,
                            '<class \'torch.nn.modules.conv.Conv1d\'>': Conv1d,
-                           '<class \'torch.nn.modules.conv.Conv2d\'>': Conv2d
+                           '<class \'torch.nn.modules.conv.Conv2d\'>': Conv2d,
+                           '<class \'torch.nn.modules.conv.Conv3d\'>': Conv3d
                            }
 
-def patch_model(model, memristor_model, memristor_model_params, module_parameters_to_patch={}, mapping_routine=naive_map, p_l=None, transistor=True, programming_routine=None, scheme=memtorch.bh.Scheme.DoubleColumn, **kwargs):
+def patch_model(model, memristor_model, memristor_model_params, module_parameters_to_patch={}, mapping_routine=naive_map, p_l=None, transistor=True, programming_routine=None, programming_routine_params={'rel_tol': 0.1}, scheme=memtorch.bh.Scheme.DoubleColumn, **kwargs):
     """Method to convert a torch.nn model to a memristive model.
 
     Parameters
@@ -35,6 +37,8 @@ def patch_model(model, memristor_model, memristor_model_params, module_parameter
         Used to determine if a 1T1R (True) or 1R arrangement (False) is simulated.
     programming_routine : function
         Programming routine to use.
+    programming_routine_params : **kwargs
+        Programming routine keyword arguments.
     scheme : memtorch.bh.Scheme
         Weight representation scheme.
 
@@ -60,6 +64,7 @@ def patch_model(model, memristor_model, memristor_model_params, module_parameter
                                                       mapping_routine=mapping_routine,
                                                       transistor=transistor,
                                                       programming_routine=programming_routine,
+                                                      programming_routine_params=programming_routine_params,
                                                       p_l=p_l,
                                                       scheme=scheme,
                                                       **kwargs))
@@ -70,6 +75,7 @@ def patch_model(model, memristor_model, memristor_model_params, module_parameter
                                                       mapping_routine=mapping_routine,
                                                       transistor=transistor,
                                                       programming_routine=programming_routine,
+                                                      programming_routine_params=programming_routine_params,
                                                       p_l=p_l,
                                                       scheme=scheme,
                                                       **kwargs))
@@ -101,7 +107,7 @@ def patch_model(model, memristor_model, memristor_model_params, module_parameter
 
         if 'cpu' not in memtorch.__version__:
             torch.cuda.empty_cache()
-            
+
         self.forward_legacy(False)
         delattr(self, 'forward_legacy')
 
